==> owncloud-9.1.4.tgz: owncloud/apps/files/l10n/pt_BR.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Armazanamento não disponível",
    "Storage invalid" : "Armazenamento invávilido",
    "Unknown error" : "Erro desconhecido",
    "Unable to set upload directory." : "Impossível configurar o diretório de envio",
    "Invalid Token" : "Token inválido",
    "No file was uploaded. Unknown error" : "Nenhum arquivo foi enviado. Erro desconhecido",
    "There is no error, the file uploaded with success" : "Sem erros, o arquivo foi enviado com sucesso",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "O arquivo enviado excede a diretiva upload_max_filesize no php.ini: ",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "O arquivo carregado excede o argumento MAX_FILE_SIZE especificado no formulário HTML",
    "The uploaded file was only partially uploaded" : "O arquivo foi parcialmente enviado",
    "No file was uploaded" : "Nenhum arquivo enviado",
    "Missing a temporary folder" : "Pasta temporária não encontrada",
    "Failed to write to disk" : "Falha ao escrever no disco",
    "Not enough storage available" : "Espaço de armazenamento insuficiente",
    "The target folder has been moved or deleted." : "A pasta de destino foi movida ou excluída.",
    "Upload failed. Could not find uploaded file" : "Falha no envio. Não foi possível encontrar o arquivo enviado",
    "Upload failed. Could not get file info." : "Falha no envio. Não foi possível obter informações do arquivo.",
    "Invalid directory." : "Diretório inválido.",
    "Files" : "Arquivos",
    "All files" : "Todos os arquivos",
    "File could not be found" : "O arquivo não foi encontrado",
    "Home" : "Home",
    "Close" : "Fechar",
    "Favorites" : "Favoritos",
    "Upload cancelled." : "Envio cancelado.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Incapaz de fazer o envio de {filename}, pois é um diretório ou tem 0 bytes",
    "Total file size {size1} exceeds upload limit {size2}" : "O tamanho total do arquivo {size1} excede o limite de envio {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Não há espaço suficiente, você está enviando {size1} mas resta apenas {size2}",
    "Error uploading file \"{fileName}\": {message}" : "Erro enviando o arquivo \"{fileName}\": {message}",
    "Could not get result from server." : "Não foi possível obter o resultado do servidor.",
    "Uploading..." : "Enviando...",
    "..." : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} de {totalSize} ({bitrate})",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Envio de arquivo em andamento. Sair da página agora resultará no cancelamento do envio.",
    "Actions" : "Ações",
    "Download" : "Baixar",
    "Rename" : "Renomear",
    "Delete" : "Excluir",
    "Disconnect storage" : "Desconectar armazenamento",
    "Unshare" : "Descompartilhar",
    "Details" : "Detalhes",
    "Select" : "Selecionar",
    "Pending" : "Pendente",
    "Unable to determine date" : "Impossível determinar a data",
    "This operation is forbidden" : "Esta operação é proibida",
    "This directory is unavailable, please check the logs or contact the administrator" : "Este diretório não está disponível, por favor, verifique os logs ou entre em contato com o administrador",
    "Could not move \"{file}\", target exists" : "Não foi possível mover o \"{file}\", o alvo já existe",
    "Could not move \"{file}\"" : "Não foi possível mover \"{file}\"",
    "{newName} already exists" : "{newName} já existe",
    "Could not rename \"{fileName}\", it does not exist any more" : "Não foi possível renomear \"{fileName}\", ele já não existe",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "O nome \"{targetName}\" já está sendo usado na pasta  \"{dir}\". Por favor escolha um outro nome.",
    "Could not rename \"{fileName}\"" : "Não foi possível renomear \"{fileName}\"",
    "Could not create file \"{file}\"" : "Não foi possível criar o arquivo \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Não foi possível criar o arquivo \"{file}\" porque ele já existe",
    "Could not create folder \"{dir}\"" : "Não foi possível criar a pasta \"{dir}\"",
    "Could not create folder \"{dir}\" because it already exists" : "Não foi possível criar a pasta \"{dir}\" porque ela já existe",
    "Error deleting file \"{fileName}\"." : "Ocorreu um erro ao apagar o arquivo \"{fileName}\".",
    "No entries in this folder match '{filter}'" : "Nenhuma entrada nesta pasta coincide com '{filter}'",
    "Name" : "Nome",
    "Size" : "Tamanho",
    "Modified" : "Modificado",
    "_%n folder_::_%n folders_" : ["%n pasta","%n pastas"],
    "_%n file_::_%n files_" : ["%n arquivo","%n arquivos"],
    "{dirs} and {files}" : "{dirs} e {files}",
    "You don’t have permission to upload or create files here" : "Você não tem permissão para enviar ou criar arquivos aqui",
    "_Uploading %n file_::_Uploading %n files_" : ["Enviando %n arquivo","Enviando %n arquivos"],
    "New" : "Novo",
    "\"{name}\" is an invalid file name." : "\"{name}\" é um nome de arquivo inválido.",
    "File name cannot be empty." : "O nome do arquivo não pode estar vazio.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Armazenamento do {owner} está cheio, os arquivos não podem ser mais atualizados ou sincronizados!",
    "Your storage is full, files can not be updated or synced anymore!" : "Seu armazenamento está cheio, arquivos não podem mais ser atualizados ou sincronizados!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Armazenamento do {owner} está quase cheio ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Seu armazenamento está quase cheio ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["coincide com '{filter}'","coincide com '{filter}'"],
    "Path" : "Caminho",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "Favorito",
    "Favorite" : "Favorito",
    "Local link" : "Link local",
    "Folder" : "Pasta",
    "New folder" : "Nova pasta",
    "{newname} already exists" : "{newname} já existe",
    "Upload" : "Enviar",
    "An error occurred while trying to update the tags" : "Ocorreu um erro enquanto tentava atualizar as etiquetas",
    "A new file or folder has been <strong>created</strong>" : "Um novo arquivo ou pasta foi <strong>criado</strong>",
    "A file or folder has been <strong>changed</strong>" : "Um arquivo ou pasta foi <strong>modificado</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limite de notificações sobre a criação e alterações em seus <strong>arquivos favoritos</strong> <em>(apenas Stream)</em>",
    "A file or folder has been <strong>deleted</strong>" : "Um arquivo ou pasta foi <strong>excluído</strong>",
    "A file or folder has been <strong>restored</strong>" : "Um arquivo ou pasta foi <strong>restautado</strong>",
    "You created %1$s" : "Você criou %1$s",
    "%2$s created %1$s" : "%2$s criou %1$s",
    "%1$s was created in a public folder" : "%1$s foi criado em uma pasta pública",
    "You changed %1$s" : "Você modificou %1$s",
    "%2$s changed %1$s" : "%2$s modificou %1$s",
    "You deleted %1$s" : "Você excluiu %1$s ",
    "%2$s deleted %1$s" : "%2$s eliminou %1$s",
    "You restored %1$s" : "Você restaurou %1$s",
    "%2$s restored %1$s" : "%2$s restaurou %1$s",
    "Changed by %2$s" : "Modificado por %2$s",
    "Deleted by %2$s" : "Deletado por %2$s",
    "Restored by %2$s" : "Restaurado por %2$s",
    "Upload (max. %s)" : "Envio (max. %s)",
    "File handling" : "Tratamento de Arquivo",
    "Maximum upload size" : "Tamanho máximo para envio",
    "max. possible: " : "max. possível:",
    "Save" : "Salvar",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Com PHP-FPM pode demorar 5 minutos para que as alterações sejam aplicadas.",
    "Missing permissions to edit from here." : "Faltando permissões para editar a partir daqui.",
    "Settings" : "Configurações",
    "Show hidden files" : "Mostrar arquivos escondidos",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Use este endereço <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">para  acessar seus Arquivos via WebDAV</a>",
    "No files in here" : "Nenhum arquivo aqui",
    "Upload some content or sync with your devices!" : "Carregue algum conteúdo ou sincronize com seus dispositivos!",
    "No entries found in this folder" : "Nenhuma entrada foi encontrada nesta pasta",
    "Select all" : "Selecionar tudo",
    "Upload too large" : "Arquivo muito grande para envio",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Os arquivos que você está tentando enviar excedeu o tamanho máximo para arquivos no servidor.",
    "No favorites" : "Sem favoritos",
    "Files and folders you mark as favorite will show up here" : "Arquivos e pastas que você marcou como favoritos são mostrados aqui",
    "Text file" : "Arquivo texto",
    "New text file.txt" : "Novo texto file.txt"
},
"nplurals=2; plural=(n > 1);");

==> owncloud-10.0.7.tgz: owncloud/apps/files/l10n/pt_BR.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "O armazenamento está temporariamente indisponível",
    "Storage invalid" : "Armazenamento invávilido",
    "Unknown error" : "Erro desconhecido",
    "All files" : "Todos os arquivos",
    "Saved" : "Salvo",
    "There was an error saving" : "Ocorreu um erro ao salvar",
    "File could not be found" : "O arquivo não foi encontrado",
    "Home" : "Home",
    "Close" : "Fechar",
    "Favorites" : "Favoritos",
    "Could not create folder \"{dir}\"" : "Não foi possível criar a pasta \"{dir}\"",
    "Upload cancelled." : "Envio cancelado.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Incapaz de fazer o envio de {filename}, pois é um diretório ou tem 0 bytes",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Não há espaço suficiente, você está enviando {size1} mas resta apenas {size2}",
    "Target folder \"{dir}\" does not exist any more" : "A pasta alvo \"{dir}\" não existe mais",
    "Target folder does not exist any more" : "Pasta de destino não existe mais",
    "Not enough free space" : "Não há espaço livre suficiente",
    "Uploading..." : "Enviando...",
    "..." : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} de {totalSize} ({bitrate})",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Envio de arquivo em andamento. Sair da página agora resultará no cancelamento do envio.",
    "Actions" : "Ações",
    "Download" : "Baixar",
    "Rename" : "Renomear",
    "Delete" : "Excluir",
    "Disconnect storage" : "Desconectar armazenamento",
    "Unshare" : "Descompartilhar",
    "Could not load info for file \"{file}\"" : "Não foi possível carregar informações para o arquivo \"{file}\"",
    "Files" : "Arquivos",
    "Details" : "Detalhes",
    "Select" : "Selecionar",
    "Pending" : "Pendente",
    "Unable to determine date" : "Impossível determinar a data",
    "Invalid path" : "Caminho inválido",
    "This operation is forbidden" : "Esta operação é proibida",
    "This directory is unavailable, please check the logs or contact the administrator" : "Este diretório não está disponível, por favor, verifique os logs ou entre em contato com o administrador",
    "Could not move \"{file}\", target exists" : "Não foi possível mover o \"{file}\", o alvo já existe",
    "Could not move \"{file}\"" : "Não foi possível mover \"{file}\"",
    "{newName} already exists" : "{newName} já existe",
    "Could not rename \"{fileName}\", it does not exist any more" : "Não foi possível renomear \"{fileName}\", ele já não existe",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "O nome \"{targetName}\" já está sendo usado na pasta  \"{dir}\". Por favor escolha um outro nome.",
    "Could not rename \"{fileName}\"" : "Não foi possível renomear \"{fileName}\"",
    "Could not create file \"{file}\"" : "Não foi possível criar o arquivo \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Não foi possível criar o arquivo \"{file}\" porque ele já existe",
    "Could not create folder \"{dir}\" because it already exists" : "Não foi possível criar a pasta \"{dir}\" porque ela já existe",
    "Error deleting file \"{fileName}\"." : "Ocorreu um erro ao apagar o arquivo \"{fileName}\".",
    "No entries in this folder match {filter}" : "Nenhuma entrada nesta pasta coincide {filter}",
    "Name" : "Nome",
    "Size" : "Tamanho",
    "Modified" : "Modificado",
    "_%n folder_::_%n folders_" : ["%n pasta","%n pastas"],
    "_%n file_::_%n files_" : ["%n arquivo","%n arquivos"],
    "{dirs} and {files}" : "{dirs} e {files}",
    "_including %n hidden_::_including %n hidden_" : ["incluindo %n escondidos","incluindo %n escondido"],
    "You don’t have permission to upload or create files here" : "Você não tem permissão para enviar ou criar arquivos aqui",
    "_Uploading %n file_::_Uploading %n files_" : ["Enviando %n arquivo","Enviando %n arquivos"],
    "New" : "Novo",
    "\"{name}\" is an invalid file name." : "\"{name}\" é um nome de arquivo inválido.",
    "File name cannot be empty." : "O nome do arquivo não pode estar vazio.",
    "\"{name}\" has a forbidden file type/extension." : "\"{name}\" tem um tipo/extensão de arquivo proibido.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Armazenamento do {owner} está cheio, os arquivos não podem ser mais atualizados ou sincronizados!",
    "Your storage is full, files can not be updated or synced anymore!" : "Seu armazenamento está cheio, arquivos não podem mais ser atualizados ou sincronizados!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Armazenamento do {owner} está quase cheio ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Seu armazenamento está quase cheio ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["coincide com '{filter}'","coincide com '{filter}'"],
    "Path" : "Caminho",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "Favorito",
    "Favorite" : "Favorito",
    "Private link:  Only people who have access to the file/folder can use it. Use it as a permanent link for yourself or to point others to files within shares" : "Link privado: Somente as pessoas que têm acesso ao arquivo/pasta podem usá-lo. Use-o como um link permanente para si mesmo ou para encaminhar outros para arquivos dentro de compartilhamentos",
    "Folder" : "Pasta",
    "New folder" : "Nova pasta",
    "{newname} already exists" : "{newname} já existe",
    "Upload" : "Enviar",
    "An error occurred while trying to update the tags" : "Ocorreu um erro enquanto tentava atualizar as etiquetas",
    "A new file or folder has been <strong>created</strong>" : "Um novo arquivo ou pasta foi <strong>criado</strong>",
    "A file or folder has been <strong>changed</strong>" : "Um arquivo ou pasta foi <strong>modificado</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limite de notificações sobre a criação e alterações em seus <strong>arquivos favoritos</strong> <em>(apenas Stream)</em>",
    "A file or folder has been <strong>deleted</strong>" : "Um arquivo ou pasta foi <strong>excluído</strong>",
    "A file or folder has been <strong>restored</strong>" : "Um arquivo ou pasta foi <strong>restautado</strong>",
    "You created %1$s" : "Você criou %1$s",
    "%2$s created %1$s" : "%2$s criou %1$s",
    "%1$s was created in a public folder" : "%1$s foi criado em uma pasta pública",
    "You changed %1$s" : "Você modificou %1$s",
    "%2$s changed %1$s" : "%2$s modificou %1$s",
    "You deleted %1$s" : "Você excluiu %1$s ",
    "%2$s deleted %1$s" : "%2$s eliminou %1$s",
    "You restored %1$s" : "Você restaurou %1$s",
    "%2$s restored %1$s" : "%2$s restaurou %1$s",
    "Changed by %2$s" : "Modificado por %2$s",
    "Deleted by %2$s" : "Deletado por %2$s",
    "Restored by %2$s" : "Restaurado por %2$s",
    "Upload (max. %s)" : "Envio (max. %s)",
    "File handling" : "Tratamento de Arquivo",
    "Maximum upload size" : "Tamanho máximo para envio",
    "max. possible: " : "max. possível:",
    "Save" : "Salvar",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Com PHP-FPM pode demorar 5 minutos para que as alterações sejam aplicadas.",
    "Missing permissions to edit from here." : "Faltando permissões para editar a partir daqui.",
    "Settings" : "Configurações",
    "Show hidden files" : "Mostrar arquivos escondidos",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Use este endereço <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">para  acessar seus Arquivos via WebDAV</a>",
    "No files in here" : "Nenhum arquivo aqui",
    "Upload some content or sync with your devices!" : "Carregue algum conteúdo ou sincronize com seus dispositivos!",
    "No entries found in this folder" : "Nenhuma entrada foi encontrada nesta pasta",
    "Select all" : "Selecionar tudo",
    "Upload too large" : "Arquivo muito grande para envio",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Os arquivos que você está tentando enviar excedeu o tamanho máximo para arquivos no servidor.",
    "No favorites" : "Sem favoritos",
    "Files and folders you mark as favorite will show up here" : "Arquivos e pastas que você marcou como favoritos são mostrados aqui",
    "Text file" : "Arquivo texto",
    "New text file.txt" : "Novo texto file.txt"
},
"nplurals=2; plural=(n > 1);");
